@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 """
 Copyright (c) Facebook, Inc. and its affiliates.
-
 This source code is licensed under the MIT license found in the
 LICENSE file in the root directory of this source tree.
 """
@@ -12,12 +11,14 @@ import tempfile
 
 from ._graph import *
 from ._graph import __version__
+from ._device import *
 from ._functions import *
 from ._autograd import *
+from ._creations import *
 from ._utils import *
 from ._rand import *
-from ._creations import *
 from ._parallel import *
+from . import cuda
 
 def draw(graph, file_name, isymbols={}, osymbols={}):
     ext = os.path.splitext(file_name)[1]
